Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(873)

Unified Diff: runtime/vm/raw_object.h

Issue 8247014: Changes to handle unresolved qualified identifiers. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: '' Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/raw_object.h
===================================================================
--- runtime/vm/raw_object.h (revision 383)
+++ runtime/vm/raw_object.h (working copy)
@@ -16,6 +16,7 @@
// Macrobatics to define the Object hierarchy of VM implementation classes.
#define CLASS_LIST_NO_OBJECT(V) \
V(Class) \
+ V(UnresolvedClass) \
V(Type) \
V(ParameterizedType) \
V(TypeParameter) \
@@ -222,6 +223,19 @@
};
+class RawUnresolvedClass : public RawObject {
+ RAW_HEAP_OBJECT_IMPLEMENTATION(UnresolvedClass);
+
+ RawObject** from() {
+ return reinterpret_cast<RawObject**>(&ptr()->qualifier_);
+ }
+ RawString* qualifier_; // Qualifier for the identifier.
+ RawString* ident_; // name of the unresolved identifier.
+ RawObject** to() { return reinterpret_cast<RawObject**>(&ptr()->ident_); }
+ intptr_t token_index_;
+};
+
+
class RawType : public RawObject {
RAW_HEAP_OBJECT_IMPLEMENTATION(Type);
@@ -242,7 +256,7 @@
RawObject** from() {
return reinterpret_cast<RawObject**>(&ptr()->type_class_);
}
- RawObject* type_class_; // Either resolved class or class name.
+ RawObject* type_class_; // Either resolved class or unresolved class.
RawTypeArguments* arguments_;
RawObject** to() { return reinterpret_cast<RawObject**>(&ptr()->arguments_); }
int8_t type_state_;
« runtime/vm/parser.cc ('K') | « runtime/vm/parser.cc ('k') | runtime/vm/raw_object.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698